#include "..\script_component.hpp"

/*
 * Function: ramdb_db_fnc_listGet
 * Author: Creedcoder, J.Schmidt
 * Edit: 07.15.2024
 * Copyright © 2024 Creedcoder, J.Schmidt, All rights reserved
 *
 * Do not edit without permission!
 *
 * This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 * To view a copy of this license, vist https://creativecommons.org/licenses/by-nc-sa/4.0/ or send a letter to Creative Commons,
 * PO Box 1866, Mountain View, CA 94042
 *
 * [Description]
 * Get element of list stored at key from DB.
 *
 * Arguments:
 * 0: Name of stored key <STRING> (default: "")
 * 1: Index of stored value in list <NUMBER> (default: -1)
 * 2: Name of function to return data <STRING> (default: "")
 * 3: Unscheduled environment <BOOL> (default: false)
 * 4: NetID of target to return data from function <STRING> (default: nil)
 *
 * Return Value:
 * N/A
 *
 * Examples:
 * ["events", 0, "ramdb_db_fnc_test", false] call ramdb_db_fnc_listGet (Server or Singleplayer Only)
 * ["events", 0, "ramdb_db_fnc_test", false, netId player] remoteExecCall ["ramdb_db_fnc_listGet", 2, false] (Multiplayer Only)
 *
 * Public: Yes
 */

params [["_key", "", [""]], ["_index", -1, [0]], ["_function", "", [""]], ["_call", false, [false]], ["_netId", "", [""]]];

diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_listGet' Key: '%1', Index: '%2', Function: '%3', Call: '%4', NetId: '%5'", _key, _index, _function, _call, _netId];

if (_key == "" || _function == "") exitWith {
	diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_listGet' Invalid Input for Key '%1' or Function '%2'", _key, _function];
};

private _return = "";

if (_netId != "") then {
	diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_listGet' Using NetId: '%1'", _netId];
	if (_call) then {
		_return = "ArmaRAMDb" callExtension ["listidx", [_key, _index, _function, _netId, _call]];
	} else {
		_return = "ArmaRAMDb" callExtension ["listidx", [_key, _index, _function, _netId]];
	};
} else {
	diag_log text "ArmaRAMDb: 'ramdb_db_fnc_listGet' Using current player";
	if (_call) then {
		_return = "ArmaRAMDb" callExtension ["listidx", [_key, _index, _function, _call]];
	} else {
		_return = "ArmaRAMDb" callExtension ["listidx", [_key, _index, _function]];
	};
};

diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_listGet' Return: '%1'", _return];
[(_return select 0)] call FUNC(scheduler);